@@ -82,7 +82,14 @@ class LoadResources(LoadData):
 
             emp.dateFrom = employment.date_from
             emp.dateTo = employment.date_to
+            if not emp.active():
+                continue
+
             emp.save()
+            if emp.mainPosition:
+                resource_obj.mainPosition = emp
+                resource_obj.save()
+
             orphans = orphans.exclude(id=emp.id)
 
         orphans.delete()
